@@ -540,3 +540,15 @@ def query_file_versions(
     ).to_pandas()
 
     return file_list
+
+
+def delete_file(id):
+    """
+    Delete file from Cognite
+    
+    Params:
+        - id: dictionary with id type (either "id" or "external_id") as key
+    """
+    client = global_client["files"]
+    client.files.delete(**id)
+    logging.debug(f"Deleted file with {id=}")
\ No newline at end of file
