@@ -174,4 +174,31 @@ def get_model_version_overview(model_name=None, env=None, metadata={}):
     if env:
         index = file_list.externalId.str.contains("/" + env + "/")
         file_list = file_list.loc[index]
-    return file_list
\ No newline at end of file
+    return file_list
+
+
+def delete_model_version(external_id, confirm=True):
+    """
+    Delete a model artifact version
+
+    Input:
+        - external_id: (string) artifact's external id in CDF Files. 
+            Model Manager builds external ids for the artifacts as follows: 
+            "model_name/environment/version". This can be obtained from 
+            the function `get_model_version_overview`
+        - confirm: (bool) whether the user will be asked to confirm deletion
+    """
+    model, environment, version = external_id.split("/")
+    confirmed = False
+
+    if confirm:
+        def confirm_prompt(question):
+            reply = None
+            while reply not in ("y", "n"):
+                reply = input(f"{question} (y/n): ").lower()
+            return (reply == "y")
+        question = f"Delete {model=}, {environment=}, {version=}?"
+        confirmed = confirm_prompt(question)
+
+    if not confirm or confirmed:
+        cdf.delete_file(dict(external_id=external_id))
\ No newline at end of file
